==> entity_display_json-1.0.2.tar.gz: entity_display_json/src/Controller/EntityDisplayJsonController.php <==
<?php

namespace Drupal\entity_display_json\Controller;

use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Entity\EntityDisplayRepositoryInterface;

/**
 * Returns responses for Entity Display JSON routes.
 */
class EntityDisplayJsonController extends ControllerBase {

  /**
   * The entity field manager.
   *
   * @var \Drupal\Core\Entity\EntityFieldManagerInterface
   */
  protected $entityFieldManager;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The entity display repository.
   *
   * @var \Drupal\Core\Entity\EntityDisplayRepositoryInterface
   */
  protected $entityDisplayRepository;

  /**
   * JsonController constructor.
   *
   * @param \Drupal\Core\Entity\EntityFieldManagerInterface $entity_field_manager
   *   The entity field manager.
   *  @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *    The entity type manager.
   * @param \Drupal\Core\Entity\EntityDisplayRepositoryInterface $entity_display_repository
   *  The entity display repository.
   */
  public function __construct(EntityFieldManagerInterface $entity_field_manager, EntityTypeManagerInterface $entity_type_manager, EntityDisplayRepositoryInterface $entity_display_repository) {
    $this->entityFieldManager = $entity_field_manager;
    $this->entityTypeManager = $entity_type_manager;
    $this->entityDisplayRepository = $entity_display_repository;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_field.manager'),
      $container->get('entity_type.manager'),
      $container->get('entity_display.repository')
    );
  }

  /**
   * Get a paragraph and view mode and display it as JSON.
   * {@inheritdoc}
   */
  public function process_entity($entity, $display_id = 'default') {
    $entity_type = $entity->getEntityTypeId();
    $bundle = $entity->bundle();
    $data = [];
    $data['entity_type'] = $entity_type;
    $data['uuid'] = $entity->uuid();
    $data['id'] = $entity->id();
    if($entity_type == 'view') {
      $data['display_id'] = $display_id;
      return $data;
    }
    $data['bundle'] = $bundle;
    $fields = $this->entityDisplayRepository->getViewDisplay($entity_type, $bundle, $display_id)->getComponents();
    foreach ($fields as $field_name => $field_value) {
      if (!$field_value['label']) {
        continue;
      }
      // Entity reference fields.
      if ($entity->$field_name->target_id) {
        $ref_entities = $entity->$field_name->referencedEntities();
        $display_id = $field_value["settings"]["view_mode"];
        foreach ($ref_entities as $ref_entity) {
          if ($field_name == 'thumbnail') {
            $image_style = $field_value["settings"]["image_style"];
            $imageUri = $ref_entity->getFileUri();
            $data[$field_name][] = \Drupal\image\Entity\ImageStyle::load($image_style)->buildUrl($imageUri);
            continue;
          }
          $data[$field_name][] = self::process_entity($ref_entity, $display_id ?? $entity->$field_name->display_id);
        }
      }
      if ($entity->$field_name->value) {
        $data[$field_name] = $entity->$field_name->value;
      }
    }
    return $data;
  }
  /**
   * Generates the JSON response based on entity display settings.
   *
   * @param string $entity_id
   *   The entity ID.
   * @param string $display_id
   *   The display ID.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   The JSON response.
   *
   * @throws \Symfony\Component\HttpKernel\Exception\NotFoundHttpException
   *   Thrown when the entity or display cannot be found.
   */
  public function build($entity_type, $uuid, $display_id = 'default') {

    $entity = reset($this->entityTypeManager->getStorage($entity_type)->loadByProperties(['uuid' => $uuid]));
    if (!$entity) {
      throw new NotFoundHttpException(sprintf('Entity with UUID %s not found.', $uuid));
    }
    $data = $this->process_entity($entity, $display_id);

    // Return the JSON response.
    return new JsonResponse($data);
  }
}

==> entity_display_json-1.0.3.tar.gz: entity_display_json/src/Controller/EntityDisplayJsonController.php <==
<?php

namespace Drupal\entity_display_json\Controller;

use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Entity\EntityDisplayRepositoryInterface;
use Drupal\path_alias\AliasManagerInterface;

/**
 * Returns responses for Entity Display JSON routes.
 */
class EntityDisplayJsonController extends ControllerBase {

  /**
   * The entity field manager.
   *
   * @var \Drupal\Core\Entity\EntityFieldManagerInterface
   */
  protected $entityFieldManager;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The entity display repository.
   *
   * @var \Drupal\Core\Entity\EntityDisplayRepositoryInterface
   */
  protected $entityDisplayRepository;

  /**
   * The entity display repository.
   *
   * @var Drupal\path_alias\AliasManagerInterface
   */
  protected $aliasManager;

  /**
   * JsonController constructor.
   *
   * @param \Drupal\Core\Entity\EntityFieldManagerInterface $entity_field_manager
   *   The entity field manager.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *    The entity type manager.
   * @param \Drupal\Core\Entity\EntityDisplayRepositoryInterface $entity_display_repository
   *  The entity display repository.
   * @param Drupal\path_alias\AliasManagerInterface $aliasManager
   *  The entity type manager.
   */
  public function __construct(EntityFieldManagerInterface $entity_field_manager, EntityTypeManagerInterface $entity_type_manager, EntityDisplayRepositoryInterface $entity_display_repository, AliasManagerInterface $aliasManager) {
    $this->entityFieldManager = $entity_field_manager;
    $this->entityTypeManager = $entity_type_manager;
    $this->entityDisplayRepository = $entity_display_repository;
    $this->aliasManager = $aliasManager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_field.manager'),
      $container->get('entity_type.manager'),
      $container->get('entity_display.repository'),
      $container->get('path_alias.manager')
    );
  }

  /**
   * Get a paragraph and view mode and display it as JSON.
   * {@inheritdoc}
   */
    public function process_entity($entity, $display_id = 'default') {
    $entity_type = $entity->getEntityTypeId();
    $bundle = $entity->bundle();
    $data = [];
    $data['entity_type'] = $entity_type;
    $data['uuid'] = $entity->uuid();
    $data['id'] = $entity->id();
    $data['langcode'] = $entity->language()->getId();

    if ($entity->hasLinkTemplate('canonical')){
      $path = $entity->toUrl()->getInternalPath();
      $data['path_alias'] = $this->aliasManager->getAliasByPath('/' . $path);
   }

    if ($entity_type == 'view') {
      $data['display_id'] = $display_id;
      return $data;
    }
    $data['bundle'] = $bundle;
    $fields = $this->entityDisplayRepository->getViewDisplay($entity_type, $bundle, $display_id)->getComponents();
    foreach ($fields as $field_name => $field_value) {
      if (!$field_value['label']) {
        continue;
      }
      // Entity reference fields.
      if ($entity->$field_name->target_id) {
        $ref_entities = $entity->$field_name->referencedEntities();
        $display_id = $field_value["settings"]["view_mode"];
        foreach ($ref_entities as $ref_entity) {
          if ($field_name == 'thumbnail') {
            $image_style = $field_value["settings"]["image_style"];
            $imageUri = $ref_entity->getFileUri();
            $data[$field_name][] = \Drupal\image\Entity\ImageStyle::load($image_style)->buildUrl($imageUri);
            continue;
          }
          $data[$field_name][] = self::process_entity($ref_entity, $display_id ?? $entity->$field_name->display_id);
        }
      }
      if ($entity->$field_name->value) {
        $data[$field_name] = $entity->$field_name->value;
      }
    }
    return $data;
  }
  /**
   * Generates the JSON response based on entity display settings.
   *
   * @param string $entity_id
   *   The entity ID.
   * @param string $display_id
   *   The display ID.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   The JSON response.
   *
   * @throws \Symfony\Component\HttpKernel\Exception\NotFoundHttpException
   *   Thrown when the entity or display cannot be found.
   */
  public function build($entity_type, $uuid, $display_id = 'default') {

    $entity = reset($this->entityTypeManager->getStorage($entity_type)->loadByProperties(['uuid' => $uuid]));
    if (!$entity) {
      throw new NotFoundHttpException(sprintf('Entity with UUID %s not found.', $uuid));
    }
      $data = $this->process_entity($entity, $display_id);

    // Return the JSON response.
    return new JsonResponse($data);
  }
}
